@@ -6,7 +6,7 @@ import webob
 class Response(webob.Response):
 
     def _get__doc(self):
-        return PyQuery(self.body)
+        return PyQuery(self.body, parser='html')
 
     def _set__doc(self, value):
         self.body = tostring(value[0])
